@@ -40,7 +40,7 @@ from disspy.application_commands import (
 )
 from disspy.channel import (
     DisChannel,
-    DisDm
+    DisDmChannel
 )
 from disspy.client import (
     DisBot,
@@ -67,13 +67,17 @@ from disspy.errors import (
     BotStatusError,
     ClassTypeError,
     BotApplicationIdInvalid,
-    BotEventVisibleError
+    BotEventVisibleError,
+    ApplicationIdIsNone,
+    Unauthorized
 )
 from disspy.guild import DisGuild
 from disspy.logger import Logger
 from disspy.message import (
     DisMessage,
-    MessageDeleteEvent
+    DmMessage,
+    MessageDeleteEvent,
+    DmMessageDeleteEvent
 )
 from disspy.user import DisUser
 from disspy.reaction import (
@@ -106,18 +110,15 @@ def _all_generator(alls: list[tuple]) -> tuple:
 
     return tuple(r)
 
-
-# Version of dipsy (b - beta, a - alpha)
-__version__ = "0.3"
-
-# Minimal python version for using package
-__pythonversion__ = "3.8"
+# Varibles
+# Version of disspy (b - beta, a - alpha)
+__version__ = "0.4"
 
 # Link to GitHub repo
 __github__ = "https://github.com/itttgg/dispy"
 
 # Link to stable version of package
-__stableversion__ = f"https://github.com/itttgg/dispy/releases/tag/{__version__}"
+__latest_version__ = f"https://github.com/itttgg/dispy/releases/latest"
 
 # Description of package
 __description__ = "Dispy - package for creating bots in discord."
@@ -149,27 +150,3 @@ __alls__: list[tuple] = [
 ]
 
 __all__: tuple = _all_generator(__alls__)
-
-
-# Info
-def __info__():
-    from time import sleep as tsleep
-
-    print(
-        "Dispy is package for creating bots in Discord. This use aiohttp, requests and other packages for using discord API")
-
-    tsleep(1)  # 1-second sleep
-
-    print("""
-For staring you must create DisBot object:
-                    
-    import disspy
-        
-    bot = disspy.DisBot("YOUR_TOKEN")
-        
-    bot.run()
-        
-run() method use for running bot Gateway client and starting bot work.
-    """)
-
-    del tsleep  # Delete import
