@@ -30,7 +30,8 @@ from typing import (
     Optional,
     Union,
     final,
-    ClassVar
+    ClassVar,
+    Any
 )
 
 from disspy.embed import DisEmbed
@@ -87,21 +88,26 @@ class _SendingRestHandler:
 
         async with ClientSession(headers={'Authorization': f'Bot {token}', 'content-type': 'application/json'}) as s:
             _u = f"https://discord.com/api/v10{endpoint}"
-            print(_u)
+
             await s.put(_u)
 
+    @staticmethod
+    async def delete_message(url, token):
+        from aiohttp import ClientSession
+
+        async with ClientSession(headers={'Authorization': f'Bot {token}', 'content-type': 'application/json'}) as s:
+            await s.delete(url=url)
+
 
 @final
 class DisMessage:
     def __init__(self, _data, _token):
         from disspy.channel import DisChannel
 
-        self._json = _data
+        self.json = _data
 
         self.channel = DisChannel(_data["channel_id"], _token)
 
-        self._headers = {'Authorization': f'Bot {_token}'}
-
         self.content: str = str(_data["content"])
 
         self.id: int = int(_data["id"])
@@ -115,7 +121,7 @@ class DisMessage:
     def is_default(self) -> bool:
         return self._type == _MessageType.DEFAULT
 
-    async def reply(self, content: Optional[str] = None, embeds: Optional[list[DisEmbed]] = None):
+    async def reply(self, content: Optional[Any] = None, embeds: Optional[list[DisEmbed]] = None):
         _d = {
             "content": None,
             "embeds": {},
@@ -124,6 +130,8 @@ class DisMessage:
             }
         }
 
+        content = str(content)
+
         if content:
             _d["content"] = content
 
@@ -140,7 +148,7 @@ class DisMessage:
 
         await _SendingRestHandler.execute(self.channel.id, _d, self._t)
 
-    async def reply(self, content: Optional[str] = None, embed: Optional[DisEmbed] = None):
+    async def reply(self, content: Optional[Any] = None, embed: Optional[DisEmbed] = None):
         _d = {
             "content": None,
             "embeds": {},
@@ -149,6 +157,94 @@ class DisMessage:
             }
         }
 
+        content = str(content)
+
+        if embed:
+            _d["embeds"] = [_EmbedGenerator(embed)]
+
+        if content:
+            _d["content"] = content
+
+        if not content and not embed:
+            return
+
+        await _SendingRestHandler.execute(self.channel.id, _d, self._t)
+
+    async def create_reaction(self, emoji: Union[DisEmoji, str]) -> DisOwnReaction:
+        if isinstance(emoji, DisEmoji):
+            if emoji.type == "custom":
+                emoji = f"{emoji.name}:{str(emoji.emoji_id)}"
+            elif emoji.type == "normal":
+                emoji = emoji.unicode
+
+        await _SendingRestHandler.create_reaction(f"/channels/{self.channel.id}/messages/{self.id}/reactions/{emoji}/@me", self._t)
+
+        return DisOwnReaction(emoji, self.id, self.channel.id, self._t)
+
+    async def delete(self):
+        _u = f"https://discord.com/api/v10/channels/{self.channel.id}/messages/{self.id}"
+
+        await _SendingRestHandler.delete_message(_u, self._t)
+
+
+class DmMessage:
+    def __init__(self, d, token):
+        from disspy.channel import DisDmChannel
+
+        self.json = d
+        self._t = token
+
+        self.id = d["id"]
+
+        self.content = d["content"]
+        self.channel = DisDmChannel(d["channel_id"], self._t)
+
+        self._type: int = int(d["type"])
+
+    def is_reply(self) -> bool:
+        return self._type == _MessageType.REPLY
+
+    def is_default(self) -> bool:
+        return self._type == _MessageType.DEFAULT
+
+    async def reply(self, content: Optional[Any] = None, embeds: Optional[list[DisEmbed]] = None):
+        _d = {
+            "content": None,
+            "embeds": {},
+            "message_reference": {
+                "message_id": self.id
+            }
+        }
+
+        content = str(content)
+
+        if content:
+            _d["content"] = content
+
+        if embeds:
+            embeds_jsons = []
+
+            for i in embeds:
+                embeds_jsons.append(_EmbedGenerator(i))
+
+            _d["embeds"] = embeds_jsons
+
+        if not embeds and not content:
+            return
+
+        await _SendingRestHandler.execute(self.channel.id, _d, self._t)
+
+    async def reply(self, content: Optional[Any] = None, embed: Optional[DisEmbed] = None):
+        _d = {
+            "content": None,
+            "embeds": {},
+            "message_reference": {
+                "message_id": self.id
+            }
+        }
+
+        content = str(content)
+
         if embed:
             _d["embeds"] = [_EmbedGenerator(embed)]
 
@@ -178,3 +274,11 @@ class MessageDeleteEvent:
 
         self.message_id = d['id']
         self.channel = DisChannel(d['channel_id'], t)
+
+
+class DmMessageDeleteEvent:
+    def __init__(self, d: dict, t: str):
+        from disspy.channel import DisDmChannel
+
+        self.message_id = d['id']
+        self.channel = DisDmChannel(d['channel_id'], t)
