@@ -30,17 +30,20 @@ from typing import (
     Union
 )
 
+from disspy.reaction import DisEmoji
+from disspy import errors
+
 
 class Component:
     def __init__(self, ctype, custom_id=None, label=None, style=None, url=None,
                  options=None, min_values=None, max_values=None,
                  min_length=None, max_length=None, placeholder=None, required=None) -> NoReturn:
         if ctype == 1:
-            print("Action Rows don't can to use by users")
+            raise errors.MessageComponentIsBlocked("Action Rows don't can to use by users")
         else:
             if ctype == 2:
                 if not style == 5 and url and not custom_id or style == 5 and not url and custom_id:
-                    print("Error!")
+                    raise RuntimeError("Error with creating components!")
                 else:
                     self.type = ctype
                     self.custom_id = custom_id
@@ -66,9 +69,10 @@ class Component:
 
 
 class Button(Component):
-    def __init__(self, label: Text, style: Optional[int] = None, url: Optional[str] = None, custom_id: Optional[Text] = None,) -> NoReturn:
+    def __init__(self, label: Text, style: Optional[int] = None, url: Optional[str] = None,
+                 custom_id: Optional[Text] = None, ) -> NoReturn:
         if not style == 5 and url and not custom_id or style == 5 and not url and custom_id:
-            print("Error!")
+            raise RuntimeError("Error with creating buttons!")
         else:
             if style is None:  # Default
                 style = 1  # Blue
@@ -82,7 +86,6 @@ class ButtonStyle:
     RED = 4
     LINK = 5
 
-from disspy.reaction import DisEmoji
 
 class SelectMenuOption:
     def __init__(self, label: str, value: str, description: str, emoji: Union[DisEmoji, str], default: bool = False):
@@ -104,7 +107,7 @@ class SelectMenuOption:
                     "name": self.emoji.name,
                     "id": self.emoji.emoji_id
                 }
-        elif isinstance(self.emoji, str):
+        else:
             e_j = {
                 "name": self.emoji,
                 "id": None
@@ -126,7 +129,8 @@ class SelectMenu(Component):
         for i in options:
             oj.append(i.json())
 
-        super().__init__(3, custom_id=custom_id, options=oj, min_values=min_values, max_values=max_values, placeholder=placeholder)
+        super().__init__(3, custom_id=custom_id, options=oj, min_values=min_values, max_values=max_values,
+                         placeholder=placeholder)
 
 
 class TextInput(Component):
